You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by tv...@apache.org on 2013/08/25 16:17:28 UTC

svn commit: r1517295 [3/15] - in /commons/proper/jcs/trunk: ./ auxiliary-builds/javagroups/src/java/org/apache/commons/ auxiliary-builds/javagroups/src/java/org/apache/jcs/auxiliary/javagroups/ auxiliary-builds/javagroups/src/test/org/apache/commons/ a...

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/annotation/ThreadSafetyType.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/annotation/ThreadSafetyType.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/annotation/ThreadSafetyType.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/annotation/ThreadSafetyType.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.lang.annotation;
+package org.apache.commons.jcs.yajcache.lang.annotation;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/annotation/UnsupportedOperation.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/annotation/UnsupportedOperation.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/annotation/UnsupportedOperation.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/annotation/UnsupportedOperation.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.lang.annotation;
+package org.apache.commons.jcs.yajcache.lang.annotation;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/IKey.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/IKey.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/IKey.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/IKey.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.lang.ref;
+package org.apache.commons.jcs.yajcache.lang.ref;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -19,7 +19,7 @@ package org.apache.jcs.yajcache.lang.ref
  * under the License.
  */
 
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 /**
  * Interface for accessing a key.
  *

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/KeyedRefCollector.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/KeyedRefCollector.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/KeyedRefCollector.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/KeyedRefCollector.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.lang.ref;
+package org.apache.commons.jcs.yajcache.lang.ref;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -27,7 +27,7 @@ import org.apache.commons.lang3.builder.
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 /**
  * Keyed Reference garbage collector which removes stale

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/KeyedSoftReference.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/KeyedSoftReference.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/KeyedSoftReference.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/KeyedSoftReference.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.lang.ref;
+package org.apache.commons.jcs.yajcache.lang.ref;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -22,7 +22,7 @@ package org.apache.jcs.yajcache.lang.ref
 import java.lang.ref.ReferenceQueue;
 import java.lang.ref.SoftReference;
 
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 /**
  * {@link SoftReference} with an embedded key.

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/KeyedWeakReference.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/KeyedWeakReference.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/KeyedWeakReference.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/lang/ref/KeyedWeakReference.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.lang.ref;
+package org.apache.commons.jcs.yajcache.lang.ref;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -22,7 +22,7 @@ package org.apache.jcs.yajcache.lang.ref
 import java.lang.ref.ReferenceQueue;
 import java.lang.ref.WeakReference;
 
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 /**
  * {@link WeakReference} with an embedded key.
  *

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/soft/SoftRefCache.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/soft/SoftRefCache.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/soft/SoftRefCache.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/soft/SoftRefCache.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.soft;
+package org.apache.commons.jcs.yajcache.soft;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -32,15 +32,15 @@ import java.util.concurrent.atomic.Atomi
 import org.apache.commons.lang3.builder.ToStringBuilder;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.yajcache.config.PerCacheConfig;
-import org.apache.jcs.yajcache.core.CacheEntry;
-import org.apache.jcs.yajcache.core.CacheType;
-import org.apache.jcs.yajcache.core.ICache;
-import org.apache.jcs.yajcache.lang.annotation.*;
-import org.apache.jcs.yajcache.lang.ref.KeyedRefCollector;
-import org.apache.jcs.yajcache.lang.ref.KeyedSoftReference;
-import org.apache.jcs.yajcache.util.CollectionUtils;
-import org.apache.jcs.yajcache.util.EqualsUtils;
+import org.apache.commons.jcs.yajcache.config.PerCacheConfig;
+import org.apache.commons.jcs.yajcache.core.CacheEntry;
+import org.apache.commons.jcs.yajcache.core.CacheType;
+import org.apache.commons.jcs.yajcache.core.ICache;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.ref.KeyedRefCollector;
+import org.apache.commons.jcs.yajcache.lang.ref.KeyedSoftReference;
+import org.apache.commons.jcs.yajcache.util.CollectionUtils;
+import org.apache.commons.jcs.yajcache.util.EqualsUtils;
 
 
 /**

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/soft/SoftRefFileCache.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/soft/SoftRefFileCache.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/soft/SoftRefFileCache.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/soft/SoftRefFileCache.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.soft;
+package org.apache.commons.jcs.yajcache.soft;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -38,26 +38,26 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.commons.lang3.builder.ToStringBuilder;
 
-import org.apache.jcs.yajcache.beans.CacheChangeSupport;
-import org.apache.jcs.yajcache.beans.ICacheChangeListener;
-import org.apache.jcs.yajcache.lang.annotation.*;
-import org.apache.jcs.yajcache.config.PerCacheConfig;
-import org.apache.jcs.yajcache.beans.ICacheChangeListener;
-import org.apache.jcs.yajcache.beans.CacheChangeSupport;
-import org.apache.jcs.yajcache.core.CacheEntry;
-import org.apache.jcs.yajcache.core.CacheManager;
-import org.apache.jcs.yajcache.core.CacheType;
-import org.apache.jcs.yajcache.core.ICache;
-import org.apache.jcs.yajcache.file.CacheFileContent;
-import org.apache.jcs.yajcache.file.CacheFileContentType;
-import org.apache.jcs.yajcache.file.CacheFileDAO;
-import org.apache.jcs.yajcache.file.CacheFileUtils;
-import org.apache.jcs.yajcache.lang.ref.KeyedRefCollector;
-import org.apache.jcs.yajcache.lang.ref.KeyedSoftReference;
-import org.apache.jcs.yajcache.util.CollectionUtils;
-import org.apache.jcs.yajcache.util.EqualsUtils;
-import org.apache.jcs.yajcache.util.concurrent.locks.IKeyedReadWriteLock;
-import org.apache.jcs.yajcache.util.concurrent.locks.KeyedReadWriteLock;
+import org.apache.commons.jcs.yajcache.beans.CacheChangeSupport;
+import org.apache.commons.jcs.yajcache.beans.ICacheChangeListener;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.config.PerCacheConfig;
+import org.apache.commons.jcs.yajcache.beans.ICacheChangeListener;
+import org.apache.commons.jcs.yajcache.beans.CacheChangeSupport;
+import org.apache.commons.jcs.yajcache.core.CacheEntry;
+import org.apache.commons.jcs.yajcache.core.CacheManager;
+import org.apache.commons.jcs.yajcache.core.CacheType;
+import org.apache.commons.jcs.yajcache.core.ICache;
+import org.apache.commons.jcs.yajcache.file.CacheFileContent;
+import org.apache.commons.jcs.yajcache.file.CacheFileContentType;
+import org.apache.commons.jcs.yajcache.file.CacheFileDAO;
+import org.apache.commons.jcs.yajcache.file.CacheFileUtils;
+import org.apache.commons.jcs.yajcache.lang.ref.KeyedRefCollector;
+import org.apache.commons.jcs.yajcache.lang.ref.KeyedSoftReference;
+import org.apache.commons.jcs.yajcache.util.CollectionUtils;
+import org.apache.commons.jcs.yajcache.util.EqualsUtils;
+import org.apache.commons.jcs.yajcache.util.concurrent.locks.IKeyedReadWriteLock;
+import org.apache.commons.jcs.yajcache.util.concurrent.locks.KeyedReadWriteLock;
 
 
 /**

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/BeanUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/BeanUtils.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/BeanUtils.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/BeanUtils.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.util;
+package org.apache.commons.jcs.yajcache.util;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -25,7 +25,7 @@ import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 /**
  *

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/ClassUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/ClassUtils.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/ClassUtils.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/ClassUtils.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.util;
+package org.apache.commons.jcs.yajcache.util;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -22,7 +22,7 @@ package org.apache.jcs.yajcache.util;
 import java.math.BigDecimal;
 import java.math.BigInteger;
 
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 /**
  *
  * @author Hanson Char

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/CollectionUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/CollectionUtils.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/CollectionUtils.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/CollectionUtils.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.util;
+package org.apache.commons.jcs.yajcache.util;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -21,7 +21,7 @@ package org.apache.jcs.yajcache.util;
 
 import java.util.concurrent.ConcurrentHashMap;
 
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 /**
  * Collection related Utilities.

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/EqualsUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/EqualsUtils.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/EqualsUtils.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/EqualsUtils.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.util;
+package org.apache.commons.jcs.yajcache.util;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/SerializeUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/SerializeUtils.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/SerializeUtils.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/SerializeUtils.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.util;
+package org.apache.commons.jcs.yajcache.util;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -22,7 +22,7 @@ package org.apache.jcs.yajcache.util;
 import java.io.Serializable;
 import java.lang.reflect.Array;
 import org.apache.commons.lang3.SerializationUtils;
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 /**
  * @author Hanson Char

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/concurrent/locks/IKeyedReadWriteLock.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/concurrent/locks/IKeyedReadWriteLock.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/concurrent/locks/IKeyedReadWriteLock.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/concurrent/locks/IKeyedReadWriteLock.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.util.concurrent.locks;
+package org.apache.commons.jcs.yajcache.util.concurrent.locks;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -21,7 +21,7 @@ package org.apache.jcs.yajcache.util.con
 
 import java.util.concurrent.locks.Lock;
 
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 /**
  * Factory Interface for key specific ReadWriteLock.
  *

Modified: commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/concurrent/locks/KeyedReadWriteLock.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/concurrent/locks/KeyedReadWriteLock.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/concurrent/locks/KeyedReadWriteLock.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/src/org/apache/jcs/yajcache/util/concurrent/locks/KeyedReadWriteLock.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.util.concurrent.locks;
+package org.apache.commons.jcs.yajcache.util.concurrent.locks;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -27,10 +27,10 @@ import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 import org.apache.commons.lang3.builder.ToStringBuilder;
-import org.apache.jcs.yajcache.lang.ref.KeyedRefCollector;
-import org.apache.jcs.yajcache.lang.ref.KeyedWeakReference;
+import org.apache.commons.jcs.yajcache.lang.ref.KeyedRefCollector;
+import org.apache.commons.jcs.yajcache.lang.ref.KeyedWeakReference;
 
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 
 /**

Modified: commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/core/CacheManagerTest.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/core/CacheManagerTest.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/core/CacheManagerTest.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/core/CacheManagerTest.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.core;
+package org.apache.commons.jcs.yajcache.core;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -23,7 +23,7 @@ import junit.framework.*;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 /**
  *

Modified: commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/core/SafeCacheManagerTest.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/core/SafeCacheManagerTest.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/core/SafeCacheManagerTest.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/core/SafeCacheManagerTest.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.core;
+package org.apache.commons.jcs.yajcache.core;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -20,11 +20,11 @@ package org.apache.jcs.yajcache.core;
  */
 
 import junit.framework.*;
-import org.apache.jcs.yajcache.util.TestSerializable;
+import org.apache.commons.jcs.yajcache.util.TestSerializable;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 /**
  *

Modified: commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/file/CacheFileDAOTest.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/file/CacheFileDAOTest.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/file/CacheFileDAOTest.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/file/CacheFileDAOTest.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.file;
+package org.apache.commons.jcs.yajcache.file;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -25,7 +25,7 @@ import java.util.Arrays;
 import junit.framework.*;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 /**
  *

Modified: commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/file/FileContentTypeTest.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/file/FileContentTypeTest.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/lang/annotation/CopyRightApacheTest.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/lang/annotation/CopyRightApacheTest.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.lang.annotation;
+package org.apache.commons.jcs.yajcache.lang.annotation;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/soft/SoftRefCacheTest.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/soft/SoftRefCacheTest.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/soft/SoftRefCacheTest.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/soft/SoftRefCacheTest.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.soft;
+package org.apache.commons.jcs.yajcache.soft;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -23,10 +23,10 @@ import junit.framework.*;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.yajcache.core.CacheManager;
-import org.apache.jcs.yajcache.core.CacheType;
-import org.apache.jcs.yajcache.core.ICache;
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.core.CacheManager;
+import org.apache.commons.jcs.yajcache.core.CacheType;
+import org.apache.commons.jcs.yajcache.core.ICache;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 /**
  *

Modified: commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/soft/SoftRefFileCacheSafeTest.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/soft/SoftRefFileCacheSafeTest.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/soft/SoftRefFileCacheSafeTest.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/soft/SoftRefFileCacheSafeTest.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.soft;
+package org.apache.commons.jcs.yajcache.soft;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -20,13 +20,13 @@ package org.apache.jcs.yajcache.soft;
  */
 
 import junit.framework.*;
-import org.apache.jcs.yajcache.core.ICacheSafe;
+import org.apache.commons.jcs.yajcache.core.ICacheSafe;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.yajcache.core.CacheManager;
-import org.apache.jcs.yajcache.core.CacheType;
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.core.CacheManager;
+import org.apache.commons.jcs.yajcache.core.CacheType;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 /**
  *

Modified: commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/util/SerializeUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/util/SerializeUtilsTest.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/util/TestSerializable.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/util/TestSerializable.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.util;
+package org.apache.commons.jcs.yajcache.util;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -21,7 +21,7 @@ package org.apache.jcs.yajcache.util;
 
 import java.io.Serializable;
 import org.apache.commons.lang3.builder.EqualsBuilder;
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 /**
  *

Modified: commons/proper/jcs/trunk/src/aspect/GetTiming.aj
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/aspect/GetTiming.aj?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/aspect/GetTiming.aj (original)
+++ commons/proper/jcs/trunk/src/aspect/GetTiming.aj Sun Aug 25 14:17:11 2013
@@ -28,10 +28,10 @@ aspect GetTiming {
   pointcut allExecs():
 
 //       !within(GetTiming)
-     !withincode(void org.apache.jcs.utils.log.Logger.*(..))
-     && !withincode(void org.apache.jcs.utils.log.Logger.*(..))
-   && (cflow(this(org.apache.jcs.engine.control.Cache))
-//    || cflow(this(org.apache.jcs.engine.group.GroupCache))
+     !withincode(void org.apache.commons.jcs.utils.log.Logger.*(..))
+     && !withincode(void org.apache.commons.jcs.utils.log.Logger.*(..))
+   && (cflow(this(org.apache.commons.jcs.engine.control.Cache))
+//    || cflow(this(org.apache.commons.jcs.engine.group.GroupCache))
     )
 //    && !withincode(* *.getValueObj(..))
 //

Modified: commons/proper/jcs/trunk/src/aspect/ShowSlow.aj
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/aspect/ShowSlow.aj?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/aspect/ShowSlow.aj (original)
+++ commons/proper/jcs/trunk/src/aspect/ShowSlow.aj Sun Aug 25 14:17:11 2013
@@ -28,10 +28,10 @@ aspect ShowSlow {
   pointcut allExecs():
 
 //       !within(GetTiming)
-     !withincode(void org.apache.jcs.utils.log.Logger.*(..))
-     && !withincode(void org.apache.jcs.utils.log.Logger.*(..))
-//  && (cflow(this(org.apache.jcs.engine.control.Cache))
-//    || cflow(this(org.apache.jcs.engine.group.GroupCache))
+     !withincode(void org.apache.commons.jcs.utils.log.Logger.*(..))
+     && !withincode(void org.apache.commons.jcs.utils.log.Logger.*(..))
+//  && (cflow(this(org.apache.commons.jcs.engine.control.Cache))
+//    || cflow(this(org.apache.commons.jcs.engine.group.GroupCache))
 //    )
 //    && !withincode(* *.getValueObj(..))
 //

Modified: commons/proper/jcs/trunk/src/aspect/org/apache/jcs/TraceJCS.aj
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/aspect/org/apache/jcs/TraceJCS.aj?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/aspect/org/apache/jcs/TraceJCS.aj (original)
+++ commons/proper/jcs/trunk/src/aspect/org/apache/jcs/TraceJCS.aj Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs;
+package org.apache.commons.jcs;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/changes/changes.xml
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/changes/changes.xml?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/changes/changes.xml (original)
+++ commons/proper/jcs/trunk/src/changes/changes.xml Sun Aug 25 14:17:11 2013
@@ -20,6 +20,10 @@
 	</properties>
 	<body>
 		<release version="2.0" date="unreleased" description="JDK 1.5 based major release">
+            <action dev="tv" type="update">
+                Change package to org.apache.commons.jcs, groupId to org.apache.commons,
+                artifactId to commons-jcs and version to 2.0-SNAPSHOT
+            </action>
             <action dev="tv" type="fix" issue="JCS-95" due-to="Nicolas Gomez Navarrete">
                 Map region names to valid file names.
             </action>

Modified: commons/proper/jcs/trunk/src/conf/cache.ccf
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/conf/cache.ccf?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/conf/cache.ccf (original)
+++ commons/proper/jcs/trunk/src/conf/cache.ccf Sun Aug 25 14:17:11 2013
@@ -18,13 +18,13 @@
 # ################# DEFAULT CACHE REGION  #####################
 # sets the default aux value for any non configured caches
 jcs.default=DC
-jcs.default.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.default.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.default.cacheattributes.MaxObjects=200001
-jcs.default.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.default.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.default.cacheattributes.UseMemoryShrinker=true
 jcs.default.cacheattributes.MaxMemoryIdleTimeSeconds=3600
 jcs.default.cacheattributes.ShrinkerIntervalSeconds=60
-jcs.default.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.default.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.default.elementattributes.IsEternal=false
 jcs.default.elementattributes.MaxLifeSeconds=700
 jcs.default.elementattributes.IdleTime=1800
@@ -37,27 +37,27 @@ jcs.default.elementattributes.IsLateral=
 # ################# CACHE REGIONS AVAILABLE ###################
 # Regions preconfirgured for caching
 jcs.region.testCache1=DC
-jcs.region.testCache1.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.testCache1.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.testCache1.cacheattributes.MaxObjects=1000000
-jcs.region.testCache1.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.testCache1.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.region.testCache1.cacheattributes.UseMemoryShrinker=true
 jcs.region.testCache1.cacheattributes.ShrinkerIntervalSeconds=30
 jcs.region.testCache1.cacheattributes.MaxMemoryIdleTimeSeconds=300
 jcs.region.testCache1.cacheattributes.MaxSpoolPerRun=100
-jcs.region.testCache1.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.region.testCache1.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.region.testCache1.elementattributes.IsEternal=false
 jcs.region.testCache1.elementattributes.MaxLifeSeconds=60000
 jcs.region.testCache1.elementattributes.IsLateral=true
 jcs.region.testCache1.elementattributes.IsRemote=true
 
 jcs.region.testCache2=DC
-jcs.region.testCache2.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.testCache2.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.testCache2.cacheattributes.MaxObjects=100
-jcs.region.testCache2.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.testCache2.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.region.testCache2.cacheattributes.UseMemoryShrinker=true
 jcs.region.testCache2.cacheattributes.MaxMemoryIdleTimeSeconds=1000
 jcs.region.testCache2.cacheattributes.ShrinkerIntervalSeconds=40
-jcs.region.testCache2.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.region.testCache2.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.region.testCache2.elementattributes.IsEternal=false
 jcs.region.testCache2.elementattributes.MaxLifeSeconds=600
 jcs.region.testCache2.elementattributes.IsSpool=true
@@ -65,13 +65,13 @@ jcs.region.testCache2.elementattributes.
 jcs.region.testCache2.elementattributes.IsLateral=true
 
 jcs.region.testCache3=
-jcs.region.testCache3.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.testCache3.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.testCache3.cacheattributes.MaxObjects=100000
-jcs.region.testCache3.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.testCache3.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.region.testCache3.cacheattributes.UseMemoryShrinker=false
 jcs.region.testCache3.cacheattributes.MaxMemoryIdleTimeSeconds=10
 jcs.region.testCache3.cacheattributes.ShrinkerIntervalSeconds=60
-jcs.region.testCache3.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.region.testCache3.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.region.testCache3.elementattributes.IsEternal=false
 jcs.region.testCache3.elementattributes.MaxLifeSeconds=3600
 jcs.region.testCache3.elementattributes.IsSpool=true
@@ -83,23 +83,23 @@ jcs.region.testCache3.elementattributes.
 # ################# AUXILIARY CACHES AVAILABLE ################
 
 # Remote RMI cache without failover
-jcs.auxiliary.RGroup=org.apache.jcs.auxiliary.remote.RemoteCacheFactory
-jcs.auxiliary.RGroup.attributes=org.apache.jcs.auxiliary.remote.RemoteCacheAttributes
+jcs.auxiliary.RGroup=org.apache.commons.jcs.auxiliary.remote.RemoteCacheFactory
+jcs.auxiliary.RGroup.attributes=org.apache.commons.jcs.auxiliary.remote.RemoteCacheAttributes
 jcs.auxiliary.RGroup.attributes.RemoteTypeName=LOCAL
 jcs.auxiliary.RGroup.attributes.RemoteHost=localhost
 jcs.auxiliary.RGroup.attributes.RemotePort=1102
 jcs.auxiliary.RGroup.attributes.GetOnly=true
 
 # Remote RMI Cache set up to failover
-jcs.auxiliary.RFailover=org.apache.jcs.auxiliary.remote.RemoteCacheFactory
-jcs.auxiliary.RFailover.attributes=org.apache.jcs.auxiliary.remote.RemoteCacheAttributes
+jcs.auxiliary.RFailover=org.apache.commons.jcs.auxiliary.remote.RemoteCacheFactory
+jcs.auxiliary.RFailover.attributes=org.apache.commons.jcs.auxiliary.remote.RemoteCacheAttributes
 jcs.auxiliary.RFailover.attributes.RemoteTypeName=LOCAL
 jcs.auxiliary.RFailover.attributes.FailoverServers=localhost:1102
 jcs.auxiliary.RFailover.attributes.GetOnly=false
 
 # Primary Disk Cache-- faster than the rest because of memory key storage
-jcs.auxiliary.DC=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
-jcs.auxiliary.DC.attributes=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
+jcs.auxiliary.DC=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
+jcs.auxiliary.DC.attributes=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
 jcs.auxiliary.DC.attributes.DiskPath=target/test-sandbox/raf
 jcs.auxiliary.DC.attributes.MaxPurgatorySize=10000000
 jcs.auxiliary.DC.attributes.MaxKeySize=1000000
@@ -114,8 +114,8 @@ jcs.auxiliary.DC.attributes.ShutdownSpoo
 # If you want to use a separate pool for each disk cache, either use
 # the single model or define a different auxiliary for each region and use the Pooled.
 # SINGLE is best unless you ahve a huge # of regions.
-jcs.auxiliary.DC2=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
-jcs.auxiliary.DC2.attributes=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
+jcs.auxiliary.DC2=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
+jcs.auxiliary.DC2.attributes=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
 jcs.auxiliary.DC2.attributes.DiskPath=target/test-sandbox/raf
 jcs.auxiliary.DC2.attributes.MaxPurgatorySize=10000
 jcs.auxiliary.DC2.attributes.MaxKeySize=10000
@@ -125,28 +125,28 @@ jcs.auxiliary.DC2.attributes.EventQueueT
 jcs.auxiliary.DC2.attributes.EventQueuePoolName=disk_cache_event_queue
 
 # Berkeley DB JE
-jcs.auxiliary.JE=org.apache.jcs.auxiliary.disk.bdbje.BDBJECacheFactory
-jcs.auxiliary.JE.attributes=org.apache.jcs.auxiliary.disk.bdbje.BDBJECacheAttributes
+jcs.auxiliary.JE=org.apache.commons.jcs.auxiliary.disk.bdbje.BDBJECacheFactory
+jcs.auxiliary.JE.attributes=org.apache.commons.jcs.auxiliary.disk.bdbje.BDBJECacheAttributes
 jcs.auxiliary.JE.attributes.DiskPath=target/test-sandbox/bdbje-disk-cache-conc
 # the minimum cache size is 1024
 jcs.auxiliary.indexedDiskCache.attributes.CacheSize=1024
 # jcs.auxiliary.indexedDiskCache.attributes.CachePercent=0
 
 # HSQL Disk Cache -- too slow as is
-jcs.auxiliary.HDC=org.apache.jcs.auxiliary.disk.hsql.HSQLCacheFactory
-jcs.auxiliary.HDC.attributes=org.apache.jcs.auxiliary.disk.hsql.HSQLCacheAttributes
+jcs.auxiliary.HDC=org.apache.commons.jcs.auxiliary.disk.hsql.HSQLCacheFactory
+jcs.auxiliary.HDC.attributes=org.apache.commons.jcs.auxiliary.disk.hsql.HSQLCacheAttributes
 jcs.auxiliary.HDC.attributes.DiskPath=@project_home_f@hsql
 
 # JISP Disk Cache -- save memory with disk key storage
-jcs.auxiliary.JDC=org.apache.jcs.auxiliary.disk.jisp.JISPCacheFactory
-jcs.auxiliary.JDC.attributes=org.apache.jcs.auxiliary.disk.jisp.JISPCacheAttributes
+jcs.auxiliary.JDC=org.apache.commons.jcs.auxiliary.disk.jisp.JISPCacheFactory
+jcs.auxiliary.JDC.attributes=org.apache.commons.jcs.auxiliary.disk.jisp.JISPCacheAttributes
 jcs.auxiliary.JDC.attributes.DiskPath=@project_home_f@raf
 jcs.auxiliary.JDC.attributes.ClearOnStart=false
 
 # need to make put or invalidate an option
 # just a remove lock to add
-jcs.auxiliary.RC=org.apache.jcs.auxiliary.remote.RemoteCacheFactory
-jcs.auxiliary.RC.attributes=org.apache.jcs.auxiliary.remote.RemoteCacheAttributes
+jcs.auxiliary.RC=org.apache.commons.jcs.auxiliary.remote.RemoteCacheFactory
+jcs.auxiliary.RC.attributes=org.apache.commons.jcs.auxiliary.remote.RemoteCacheAttributes
 jcs.auxiliary.RC.attributes.FailoverServers=localhost:1101,localhost:1102
 jcs.auxiliary.RC.attributes.LocalPort=1201
 jcs.auxiliary.RC.attributes.RemoveUponRemotePut=false
@@ -158,42 +158,42 @@ jcs.auxiliary.RC.attributes.ThreadPoolNa
 jcs.auxiliary.RC.attributes.GetOnly=false
 
 # unreliable
-jcs.auxiliary.LUDP=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LUDP.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LUDP=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LUDP.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LUDP.attributes.TransmissionTypeName=UDP
 jcs.auxiliary.LUDP.attributes.UdpMulticastAddr=228.5.6.7
 jcs.auxiliary.LUDP.attributes.UdpMulticastPort=6789
 
-jcs.auxiliary.LJG=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LJG.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LJG=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LJG.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LJG.attributes.TransmissionTypeName=JAVAGROUPS
 jcs.auxiliary.LJG.attributes.PutOnlyMode=true
 jcs.auxiliary.LJG.attributes.JGChannelProperties = UDP(mcast_addr=224.0.0.100;mcast_port=751):PING(timeout=3000):FD:STABLE:NAKACK:UNICAST:FRAG:FLUSH:GMS:VIEW_ENFORCER:QUEUE
 
 
-jcs.auxiliary.JG = org.apache.jcs.auxiliary.javagroups.JavaGroupsCacheFactory
-jcs.auxiliary.JG.attributes = org.apache.jcs.auxiliary.javagroups.JavaGroupsCacheAttributes
+jcs.auxiliary.JG = org.apache.commons.jcs.auxiliary.javagroups.JavaGroupsCacheFactory
+jcs.auxiliary.JG.attributes = org.apache.commons.jcs.auxiliary.javagroups.JavaGroupsCacheAttributes
 jcs.auxiliary.JG.attributes.ChannelFactoryClassName = org.javagroups.JChannelFactory
 jcs.auxiliary.JG.attributes.ChannelProperties = UDP(mcast_addr=224.0.0.100;mcast_port=7501):PING:FD:STABLE:NAKACK:UNICAST:FRAG:FLUSH:GMS:VIEW_ENFORCER:QUEUE
 
 
 # almost complete
-jcs.auxiliary.LTCP=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LTCP.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LTCP=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LTCP.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LTCP.attributes.TransmissionTypeName=TCP
 jcs.auxiliary.LTCP.attributes.TcpServers=localhost:1112
 jcs.auxiliary.LTCP.attributes.TcpListenerPort=1111
 jcs.auxiliary.LTCP.attributes.PutOnlyMode=true
 
-jcs.auxiliary.LTCP2=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LTCP2.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LTCP2=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LTCP2.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LTCP2.attributes.TransmissionTypeName=TCP
 jcs.auxiliary.LTCP2.attributes.TcpServers=localhost:1112
 jcs.auxiliary.LTCP2.attributes.TcpListenerPort=1111
 jcs.auxiliary.LTCP2.attributes.PutOnlyMode=true
 
-jcs.auxiliary.XMLRPC=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.XMLRPC.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.XMLRPC=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.XMLRPC.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.XMLRPC.attributes.TransmissionTypeName=XMLRPC
 jcs.auxiliary.XMLRPC.attributes.HttpServers=localhost:8182
 jcs.auxiliary.XMLRPC.attributes.HttpListenerPort=8181
@@ -202,8 +202,8 @@ jcs.auxiliary.XMLRPC.attributes.PutOnlyM
 
 # example of how to configure the http version of the lateral cache
 # not converteed to new cache
-jcs.auxiliary.LCHTTP=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LCHTTP.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LCHTTP=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LCHTTP.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LCHTTP.attributes.TransmissionType=HTTP
 jcs.auxiliary.LCHTTP.attributes.httpServers=localhost:8080,localhost:7001,localhost:80
 jcs.auxiliary.LCHTTP.attributes.httpReceiveServlet=/cache/LateralCacheReceiverServlet

Modified: commons/proper/jcs/trunk/src/conf/cache2.ccf
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/conf/cache2.ccf?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/conf/cache2.ccf (original)
+++ commons/proper/jcs/trunk/src/conf/cache2.ccf Sun Aug 25 14:17:11 2013
@@ -18,59 +18,59 @@
 # ################# DEFAULT CACHE REGION  #####################
 # sets the default aux value for any non configured caches
 jcs.default=DC
-jcs.default.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.default.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.default.cacheattributes.MaxObjects=200000
-jcs.default.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.default.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 # should be defined for the storage of group attribute list
 jcs.system.groupIdCache=DC
-jcs.system.groupIdCache.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.system.groupIdCache.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.system.groupIdCache.cacheattributes.MaxObjects=1000
-jcs.system.groupIdCache.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.system.groupIdCache.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 
 # #############################################################
 # ################# CACHE REGIONS AVAILABLE ###################
 jcs.region.testCache1=DC,RC
-jcs.region.testCache1.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.testCache1.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.testCache1.cacheattributes.MaxObjects=10
-jcs.region.testCache1.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.testCache1.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.region.testCache1.cacheattributes.UseMemoryShrinker=true
 jcs.region.testCache1.cacheattributes.ShrinkerIntervalSeconds=30
 jcs.region.testCache1.cacheattributes.MaxMemoryIdleTimeSeconds=300
 jcs.region.testCache1.cacheattributes.MaxSpoolPerRun=100
-jcs.region.testCache1.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.region.testCache1.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.region.testCache1.elementattributes.IsEternal=false
 jcs.region.testCache1.elementattributes.MaxLifeSeconds=60000
 jcs.region.testCache1.elementattributes.IsLateral=true
 jcs.region.testCache1.elementattributes.IsRemote=true
 
 jcs.region.testCache2=DC
-jcs.region.testCache2.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.testCache2.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.testCache2.cacheattributes.MaxObjects=1000
-jcs.region.testCache2.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.testCache2.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 # prefered config
 jcs.region.test2=DC
-jcs.region.test2.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.test2.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.test2.cacheattributes.MaxObjects=1000
 
 
 # #############################################################
 # ################# AUXILIARY CACHES AVAILABLE ################
-jcs.auxiliary.HC=org.apache.jcs.auxiliary.disk.hsql.HSQLCacheFactory
-jcs.auxiliary.HC.attributes=org.apache.jcs.auxiliary.disk.hsql.HSQLCacheAttributes
+jcs.auxiliary.HC=org.apache.commons.jcs.auxiliary.disk.hsql.HSQLCacheFactory
+jcs.auxiliary.HC.attributes=org.apache.commons.jcs.auxiliary.disk.hsql.HSQLCacheAttributes
 jcs.auxiliary.HC.attributes.DiskPath=@project_home@/hsql
 
 # standard disk cache
-jcs.auxiliary.DC=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
-jcs.auxiliary.DC.attributes=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
+jcs.auxiliary.DC=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
+jcs.auxiliary.DC.attributes=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
 jcs.auxiliary.DC.attributes.DiskPath=target/test-sandbox
 
 # need to make put or invalidate an option
 # just a remove lock to add
-jcs.auxiliary.RC=org.apache.jcs.auxiliary.remote.RemoteCacheFactory
-jcs.auxiliary.RC.attributes=org.apache.jcs.auxiliary.remote.RemoteCacheAttributes
+jcs.auxiliary.RC=org.apache.commons.jcs.auxiliary.remote.RemoteCacheFactory
+jcs.auxiliary.RC.attributes=org.apache.commons.jcs.auxiliary.remote.RemoteCacheAttributes
 jcs.auxiliary.RC.attributes.FailoverServers=localhost:1101
 jcs.auxiliary.RC.attributes.LocalPort=1202
 jcs.auxiliary.RC.attributes.RemoveUponRemotePut=false
@@ -79,45 +79,45 @@ jcs.auxiliary.RC.attributes.ThreadPoolNa
 jcs.auxiliary.RC.attributes.GetOnly=false
 
 # unreliable
-jcs.auxiliary.LUDP=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LUDP.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LUDP=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LUDP.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LUDP.attributes.TransmissionTypeName=UDP
 jcs.auxiliary.LUDP.attributes.UdpMulticastAddr=228.5.6.7
 jcs.auxiliary.LUDP.attributes.UdpMulticastPort=6789
 
-jcs.auxiliary.LJG=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LJG.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LJG=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LJG.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LJG.attributes.TransmissionTypeName=JAVAGROUPS
 jcs.auxiliary.LJG.attributes.UdpMulticastAddr=228.5.6.7
 jcs.auxiliary.LJG.attributes.UdpMulticastPort=6789
 jcs.auxiliary.LJG.attributes.PutOnlyMode=true
 
 # almost complete
-jcs.auxiliary.LTCP=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LTCP.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LTCP=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LTCP.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LTCP.attributes.TransmissionTypeName=TCP
 jcs.auxiliary.LTCP.attributes.TcpServers=localhost:1111
 jcs.auxiliary.LTCP.attributes.TcpListenerPort=1112
 jcs.auxiliary.LTCP.attributes.PutOnlyMode=true
 
-jcs.auxiliary.XMLRPC=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.XMLRPC.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.XMLRPC=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.XMLRPC.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.XMLRPC.attributes.TransmissionTypeName=XMLRPC
 jcs.auxiliary.XMLRPC.attributes.HttpServers=localhost:8181
 jcs.auxiliary.XMLRPC.attributes.HttpListenerPort=8182
 jcs.auxiliary.XMLRPC.attributes.PutOnlyMode=false
 
 
-jcs.auxiliary.LTCP2=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LTCP2.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LTCP2=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LTCP2.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LTCP2.attributes.TransmissionTypeName=TCP
 jcs.auxiliary.LTCP2.attributes.TcpServers=localhost:1111,localhost2:1112
 jcs.auxiliary.LTCP2.attributes.TcpListenerPort=1111
 
 # example of how to configure the http version of the lateral cache
 # not converteed to new cache
-jcs.auxiliary.LCHTTP=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LCHTTP.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LCHTTP=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LCHTTP.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LCHTTP.attributes.TransmissionType=HTTP
 jcs.auxiliary.LCHTTP.attributes.httpServers=localhost:8080,localhost:7001,localhost:80
 jcs.auxiliary.LCHTTP.attributes.httpReceiveServlet=/cache/LateralCacheReceiverServlet

Modified: commons/proper/jcs/trunk/src/conf/cache3.ccf
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/conf/cache3.ccf?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/conf/cache3.ccf (original)
+++ commons/proper/jcs/trunk/src/conf/cache3.ccf Sun Aug 25 14:17:11 2013
@@ -18,51 +18,51 @@
 # ################# DEFAULT CACHE REGION  #####################
 # sets the default aux value for any non configured caches
 jcs.default=DC
-jcs.default.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.default.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.default.cacheattributes.MaxObjects=1000
-jcs.default.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.default.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 # should be defined for the storage of group attribute list
 jcs.system.groupIdCache=DC
-jcs.system.groupIdCache.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.system.groupIdCache.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.system.groupIdCache.cacheattributes.MaxObjects=1000
-jcs.system.groupIdCache.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.system.groupIdCache.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 
 # #############################################################
 # ################# CACHE REGIONS AVAILABLE ###################
 jcs.region.testCache1=RC
-jcs.region.testCache1.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.testCache1.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.testCache1.cacheattributes.MaxObjects=1000
-jcs.region.testCache1.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.testCache1.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.region.testCache1.elementattributes.IsLateral=true
 
 jcs.region.testCache2=DC
-jcs.region.testCache2.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.testCache2.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.testCache2.cacheattributes.MaxObjects=1000
-jcs.region.testCache2.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.testCache2.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 # prefered config
 jcs.region.test2=DC
-jcs.region.test2.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.test2.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.test2.cacheattributes.MaxObjects=1000
 
 
 # #############################################################
 # ################# AUXILIARY CACHES AVAILABLE ################
-jcs.auxiliary.HC=org.apache.jcs.auxiliary.disk.hsql.HSQLCacheFactory
-jcs.auxiliary.HC.attributes=org.apache.jcs.auxiliary.disk.hsql.HSQLCacheAttributes
+jcs.auxiliary.HC=org.apache.commons.jcs.auxiliary.disk.hsql.HSQLCacheFactory
+jcs.auxiliary.HC.attributes=org.apache.commons.jcs.auxiliary.disk.hsql.HSQLCacheAttributes
 jcs.auxiliary.HC.attributes.DiskPath=@project_home@/hsql
 
 # standard disk cache
-jcs.auxiliary.DC=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
-jcs.auxiliary.DC.attributes=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
+jcs.auxiliary.DC=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
+jcs.auxiliary.DC.attributes=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
 jcs.auxiliary.DC.attributes.DiskPath=@project_home@/raf
 
 # need to make put or invalidate an option
 # just a remove lock to add
-jcs.auxiliary.RC=org.apache.jcs.auxiliary.remote.RemoteCacheFactory
-jcs.auxiliary.RC.attributes=org.apache.jcs.auxiliary.remote.RemoteCacheAttributes
+jcs.auxiliary.RC=org.apache.commons.jcs.auxiliary.remote.RemoteCacheFactory
+jcs.auxiliary.RC.attributes=org.apache.commons.jcs.auxiliary.remote.RemoteCacheAttributes
 jcs.auxiliary.RC.attributes.RemoteHost=10.21.209.150
 jcs.auxiliary.RC.attributes.RemotePort=1102
 # jcs.auxiliary.RC.attributes.LocalPort=1103
@@ -71,45 +71,45 @@ jcs.auxiliary.RC.attributes.RemoveUponRe
 
 
 # unreliable
-jcs.auxiliary.LUDP=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LUDP.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LUDP=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LUDP.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LUDP.attributes.TransmissionTypeName=UDP
 jcs.auxiliary.LUDP.attributes.UdpMulticastAddr=228.5.6.7
 jcs.auxiliary.LUDP.attributes.UdpMulticastPort=6789
 
-jcs.auxiliary.LJG=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LJG.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LJG=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LJG.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LJG.attributes.TransmissionTypeName=JAVAGROUPS
 jcs.auxiliary.LJG.attributes.UdpMulticastAddr=228.5.6.7
 jcs.auxiliary.LJG.attributes.UdpMulticastPort=6789
 jcs.auxiliary.LJG.attributes.PutOnlyMode=true
 
 # almost complete
-jcs.auxiliary.LTCP=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LTCP.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LTCP=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LTCP.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LTCP.attributes.TransmissionTypeName=TCP
 jcs.auxiliary.LTCP.attributes.TcpServers=localhost:1111
 jcs.auxiliary.LTCP.attributes.TcpListenerPort=1112
 jcs.auxiliary.LTCP.attributes.PutOnlyMode=false
 
-jcs.auxiliary.XMLRPC=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.XMLRPC.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.XMLRPC=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.XMLRPC.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.XMLRPC.attributes.TransmissionTypeName=XMLRPC
 jcs.auxiliary.XMLRPC.attributes.HttpServers=localhost:8181
 jcs.auxiliary.XMLRPC.attributes.HttpListenerPort=8182
 jcs.auxiliary.XMLRPC.attributes.PutOnlyMode=false
 
 
-jcs.auxiliary.LTCP2=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LTCP2.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LTCP2=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LTCP2.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LTCP2.attributes.TransmissionTypeName=TCP
 jcs.auxiliary.LTCP2.attributes.TcpServers=localhost:1111,localhost2:1112
 jcs.auxiliary.LTCP2.attributes.TcpListenerPort=1111
 
 # example of how to configure the http version of the lateral cache
 # not converteed to new cache
-jcs.auxiliary.LCHTTP=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LCHTTP.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LCHTTP=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LCHTTP.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LCHTTP.attributes.TransmissionType=HTTP
 jcs.auxiliary.LCHTTP.attributes.httpServers=localhost:8080,localhost:7001,localhost:80
 jcs.auxiliary.LCHTTP.attributes.httpReceiveServlet=/cache/LateralCacheReceiverServlet

Modified: commons/proper/jcs/trunk/src/conf/cacheB.ccf
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/conf/cacheB.ccf?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/conf/cacheB.ccf (original)
+++ commons/proper/jcs/trunk/src/conf/cacheB.ccf Sun Aug 25 14:17:11 2013
@@ -18,13 +18,13 @@
 # ################# DEFAULT CACHE REGION  #####################
 # sets the default aux value for any non configured caches
 jcs.default=DC
-jcs.default.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.default.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.default.cacheattributes.MaxObjects=1000
-jcs.default.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.default.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.default.cacheattributes.UseMemoryShrinker=true
 jcs.default.cacheattributes.MaxMemoryIdleTimeSeconds=3600
 jcs.default.cacheattributes.ShrinkerIntervalSeconds=60
-jcs.default.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.default.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.default.elementattributes.IsEternal=false
 jcs.default.elementattributes.MaxLifeSeconds=700
 jcs.default.elementattributes.IdleTime=1800
@@ -37,27 +37,27 @@ jcs.default.elementattributes.IsLateral=
 # ################# CACHE REGIONS AVAILABLE ###################
 # Regions preconfirgured for caching
 jcs.region.testCache1=RC
-jcs.region.testCache1.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.testCache1.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.testCache1.cacheattributes.MaxObjects=1000
-jcs.region.testCache1.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.testCache1.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.region.testCache1.cacheattributes.UseMemoryShrinker=true
 jcs.region.testCache1.cacheattributes.ShrinkerIntervalSeconds=30
 jcs.region.testCache1.cacheattributes.MaxMemoryIdleTimeSeconds=300
 jcs.region.testCache1.cacheattributes.MaxSpoolPerRun=100
-jcs.region.testCache1.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.region.testCache1.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.region.testCache1.elementattributes.IsEternal=false
 jcs.region.testCache1.elementattributes.MaxLifeSeconds=60000
 jcs.region.testCache1.elementattributes.IsLateral=true
 jcs.region.testCache1.elementattributes.IsRemote=true
 
 jcs.region.testCache2=DC
-jcs.region.testCache2.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.testCache2.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.testCache2.cacheattributes.MaxObjects=100
-jcs.region.testCache2.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.testCache2.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.region.testCache2.cacheattributes.UseMemoryShrinker=true
 jcs.region.testCache2.cacheattributes.MaxMemoryIdleTimeSeconds=1000
 jcs.region.testCache2.cacheattributes.ShrinkerIntervalSeconds=40
-jcs.region.testCache2.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.region.testCache2.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.region.testCache2.elementattributes.IsEternal=false
 jcs.region.testCache2.elementattributes.MaxLifeSeconds=600
 jcs.region.testCache2.elementattributes.IsSpool=true
@@ -65,13 +65,13 @@ jcs.region.testCache2.elementattributes.
 jcs.region.testCache2.elementattributes.IsLateral=true
 
 jcs.region.testCache3=
-jcs.region.testCache3.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.testCache3.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.testCache3.cacheattributes.MaxObjects=100000
-jcs.region.testCache3.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.testCache3.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.region.testCache3.cacheattributes.UseMemoryShrinker=false
 jcs.region.testCache3.cacheattributes.MaxMemoryIdleTimeSeconds=10
 jcs.region.testCache3.cacheattributes.ShrinkerIntervalSeconds=60
-jcs.region.testCache3.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.region.testCache3.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.region.testCache3.elementattributes.IsEternal=false
 jcs.region.testCache3.elementattributes.MaxLifeSeconds=3600
 jcs.region.testCache3.elementattributes.IsSpool=true
@@ -83,23 +83,23 @@ jcs.region.testCache3.elementattributes.
 # ################# AUXILIARY CACHES AVAILABLE ################
 
 # Remote RMI cache without failover
-jcs.auxiliary.RGroup=org.apache.jcs.auxiliary.remote.RemoteCacheFactory
-jcs.auxiliary.RGroup.attributes=org.apache.jcs.auxiliary.remote.RemoteCacheAttributes
+jcs.auxiliary.RGroup=org.apache.commons.jcs.auxiliary.remote.RemoteCacheFactory
+jcs.auxiliary.RGroup.attributes=org.apache.commons.jcs.auxiliary.remote.RemoteCacheAttributes
 jcs.auxiliary.RGroup.attributes.RemoteTypeName=LOCAL
 jcs.auxiliary.RGroup.attributes.RemoteHost=localhost
 jcs.auxiliary.RGroup.attributes.RemotePort=1102
 jcs.auxiliary.RGroup.attributes.GetOnly=true
 
 # Remote RMI Cache set up to failover
-jcs.auxiliary.RFailover=org.apache.jcs.auxiliary.remote.RemoteCacheFactory
-jcs.auxiliary.RFailover.attributes=org.apache.jcs.auxiliary.remote.RemoteCacheAttributes
+jcs.auxiliary.RFailover=org.apache.commons.jcs.auxiliary.remote.RemoteCacheFactory
+jcs.auxiliary.RFailover.attributes=org.apache.commons.jcs.auxiliary.remote.RemoteCacheAttributes
 jcs.auxiliary.RFailover.attributes.RemoteTypeName=LOCAL
 jcs.auxiliary.RFailover.attributes.FailoverServers=localhost:1102
 jcs.auxiliary.RFailover.attributes.GetOnly=false
 
 # Primary Disk Cache-- faster than the rest because of memory key storage
-jcs.auxiliary.DC=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
-jcs.auxiliary.DC.attributes=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
+jcs.auxiliary.DC=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
+jcs.auxiliary.DC.attributes=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
 jcs.auxiliary.DC.attributes.DiskPath=target/test-sandbox/raf
 jcs.auxiliary.DC.attributes.MaxPurgatorySize=10000
 jcs.auxiliary.DC.attributes.MaxKeySize=10000
@@ -113,8 +113,8 @@ jcs.auxiliary.DC.attributes.OptimizeAtRe
 # If you want to use a separate pool for each disk cache, either use
 # the single model or define a different auxiliary for each region and use the Pooled.
 # SINGLE is best unless you ahve a huge # of regions.
-jcs.auxiliary.DC2=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
-jcs.auxiliary.DC2.attributes=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
+jcs.auxiliary.DC2=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
+jcs.auxiliary.DC2.attributes=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
 jcs.auxiliary.DC2.attributes.DiskPath=target/test-sandbox/raf
 jcs.auxiliary.DC2.attributes.MaxPurgatorySize=10000
 jcs.auxiliary.DC2.attributes.MaxKeySize=10000
@@ -124,28 +124,28 @@ jcs.auxiliary.DC2.attributes.EventQueueT
 jcs.auxiliary.DC2.attributes.EventQueuePoolName=disk_cache_event_queue
 
 # Berkeley DB JE
-jcs.auxiliary.JE=org.apache.jcs.auxiliary.disk.bdbje.BDBJECacheFactory
-jcs.auxiliary.JE.attributes=org.apache.jcs.auxiliary.disk.bdbje.BDBJECacheAttributes
+jcs.auxiliary.JE=org.apache.commons.jcs.auxiliary.disk.bdbje.BDBJECacheFactory
+jcs.auxiliary.JE.attributes=org.apache.commons.jcs.auxiliary.disk.bdbje.BDBJECacheAttributes
 jcs.auxiliary.JE.attributes.DiskPath=target/test-sandbox/bdbje-disk-cache-conc
 # the minimum cache size is 1024
 jcs.auxiliary.indexedDiskCache.attributes.CacheSize=1024
 # jcs.auxiliary.indexedDiskCache.attributes.CachePercent=0
 
 # HSQL Disk Cache -- too slow as is
-jcs.auxiliary.HDC=org.apache.jcs.auxiliary.disk.hsql.HSQLCacheFactory
-jcs.auxiliary.HDC.attributes=org.apache.jcs.auxiliary.disk.hsql.HSQLCacheAttributes
+jcs.auxiliary.HDC=org.apache.commons.jcs.auxiliary.disk.hsql.HSQLCacheFactory
+jcs.auxiliary.HDC.attributes=org.apache.commons.jcs.auxiliary.disk.hsql.HSQLCacheAttributes
 jcs.auxiliary.HDC.attributes.DiskPath=@project_home_f@hsql
 
 # JISP Disk Cache -- save memory with disk key storage
-jcs.auxiliary.JDC=org.apache.jcs.auxiliary.disk.jisp.JISPCacheFactory
-jcs.auxiliary.JDC.attributes=org.apache.jcs.auxiliary.disk.jisp.JISPCacheAttributes
+jcs.auxiliary.JDC=org.apache.commons.jcs.auxiliary.disk.jisp.JISPCacheFactory
+jcs.auxiliary.JDC.attributes=org.apache.commons.jcs.auxiliary.disk.jisp.JISPCacheAttributes
 jcs.auxiliary.JDC.attributes.DiskPath=@project_home_f@raf
 jcs.auxiliary.JDC.attributes.ClearOnStart=false
 
 # need to make put or invalidate an option
 # just a remove lock to add
-jcs.auxiliary.RC=org.apache.jcs.auxiliary.remote.RemoteCacheFactory
-jcs.auxiliary.RC.attributes=org.apache.jcs.auxiliary.remote.RemoteCacheAttributes
+jcs.auxiliary.RC=org.apache.commons.jcs.auxiliary.remote.RemoteCacheFactory
+jcs.auxiliary.RC.attributes=org.apache.commons.jcs.auxiliary.remote.RemoteCacheAttributes
 jcs.auxiliary.RC.attributes.FailoverServers=localhost:1101,localhost:1102,localhost:1103
 jcs.auxiliary.RC.attributes.LocalPort=1204
 jcs.auxiliary.RC.attributes.RemoveUponRemotePut=false
@@ -154,42 +154,42 @@ jcs.auxiliary.RC.attributes.ThreadPoolNa
 jcs.auxiliary.RC.attributes.GetOnly=false
 
 # unreliable
-jcs.auxiliary.LUDP=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LUDP.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LUDP=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LUDP.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LUDP.attributes.TransmissionTypeName=UDP
 jcs.auxiliary.LUDP.attributes.UdpMulticastAddr=228.5.6.7
 jcs.auxiliary.LUDP.attributes.UdpMulticastPort=6789
 
-jcs.auxiliary.LJG=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LJG.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LJG=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LJG.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LJG.attributes.TransmissionTypeName=JAVAGROUPS
 jcs.auxiliary.LJG.attributes.PutOnlyMode=true
 jcs.auxiliary.LJG.attributes.JGChannelProperties = UDP(mcast_addr=224.0.0.100;mcast_port=751):PING(timeout=3000):FD:STABLE:NAKACK:UNICAST:FRAG:FLUSH:GMS:VIEW_ENFORCER:QUEUE
 
 
-jcs.auxiliary.JG = org.apache.jcs.auxiliary.javagroups.JavaGroupsCacheFactory
-jcs.auxiliary.JG.attributes = org.apache.jcs.auxiliary.javagroups.JavaGroupsCacheAttributes
+jcs.auxiliary.JG = org.apache.commons.jcs.auxiliary.javagroups.JavaGroupsCacheFactory
+jcs.auxiliary.JG.attributes = org.apache.commons.jcs.auxiliary.javagroups.JavaGroupsCacheAttributes
 jcs.auxiliary.JG.attributes.ChannelFactoryClassName = org.javagroups.JChannelFactory
 jcs.auxiliary.JG.attributes.ChannelProperties = UDP(mcast_addr=224.0.0.100;mcast_port=7501):PING:FD:STABLE:NAKACK:UNICAST:FRAG:FLUSH:GMS:VIEW_ENFORCER:QUEUE
 
 
 # almost complete
-jcs.auxiliary.LTCP=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LTCP.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LTCP=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LTCP.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LTCP.attributes.TransmissionTypeName=TCP
 jcs.auxiliary.LTCP.attributes.TcpServers=localhost:1112
 jcs.auxiliary.LTCP.attributes.TcpListenerPort=1111
 jcs.auxiliary.LTCP.attributes.PutOnlyMode=false
 
-jcs.auxiliary.LTCP2=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LTCP2.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LTCP2=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LTCP2.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LTCP2.attributes.TransmissionTypeName=TCP
 jcs.auxiliary.LTCP2.attributes.TcpServers=localhost:1112
 jcs.auxiliary.LTCP2.attributes.TcpListenerPort=1111
 jcs.auxiliary.LTCP2.attributes.PutOnlyMode=true
 
-jcs.auxiliary.XMLRPC=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.XMLRPC.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.XMLRPC=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.XMLRPC.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.XMLRPC.attributes.TransmissionTypeName=XMLRPC
 jcs.auxiliary.XMLRPC.attributes.HttpServers=localhost:8182
 jcs.auxiliary.XMLRPC.attributes.HttpListenerPort=8181
@@ -198,8 +198,8 @@ jcs.auxiliary.XMLRPC.attributes.PutOnlyM
 
 # example of how to configure the http version of the lateral cache
 # not converteed to new cache
-jcs.auxiliary.LCHTTP=org.apache.jcs.auxiliary.lateral.LateralCacheFactory
-jcs.auxiliary.LCHTTP.attributes=org.apache.jcs.auxiliary.lateral.LateralCacheAttributes
+jcs.auxiliary.LCHTTP=org.apache.commons.jcs.auxiliary.lateral.LateralCacheFactory
+jcs.auxiliary.LCHTTP.attributes=org.apache.commons.jcs.auxiliary.lateral.LateralCacheAttributes
 jcs.auxiliary.LCHTTP.attributes.TransmissionType=HTTP
 jcs.auxiliary.LCHTTP.attributes.httpServers=localhost:8080,localhost:7001,localhost:80
 jcs.auxiliary.LCHTTP.attributes.httpReceiveServlet=/cache/LateralCacheReceiverServlet

Modified: commons/proper/jcs/trunk/src/conf/cacheBDB.ccf
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/conf/cacheBDB.ccf?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/conf/cacheBDB.ccf (original)
+++ commons/proper/jcs/trunk/src/conf/cacheBDB.ccf Sun Aug 25 14:17:11 2013
@@ -18,38 +18,38 @@
 # a maximum of 100 objects, so objects should get pushed into the disk cache
 
 jcs.default=bdbje
-jcs.default.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.default.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.default.cacheattributes.MaxObjects=100
-jcs.default.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.default.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 # #### CACHE REGIONS FOR TEST
 
 jcs.region.indexedRegion1=bdbje
-jcs.region.indexedRegion1.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.indexedRegion1.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.indexedRegion1.cacheattributes.MaxObjects=100
-jcs.region.indexedRegion1.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.indexedRegion1.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 jcs.region.indexedRegion2=bdbje
-jcs.region.indexedRegion2.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.indexedRegion2.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.indexedRegion2.cacheattributes.MaxObjects=100
-jcs.region.indexedRegion2.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.indexedRegion2.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 jcs.region.indexedRegion3=bdbje
-jcs.region.indexedRegion3.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.indexedRegion3.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.indexedRegion3.cacheattributes.MaxObjects=100
-jcs.region.indexedRegion3.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.indexedRegion3.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 jcs.region.indexedRegion4=bdbje
-jcs.region.indexedRegion4.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.indexedRegion4.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.indexedRegion4.cacheattributes.MaxObjects=100
-jcs.region.indexedRegion4.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.indexedRegion4.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.region.indexedRegion4.cacheattributes.UseMemoryShrinker=false
 
 
 # #### AUXILIARY CACHES
 
 # Berkeley DB JE
-jcs.auxiliary.bdbje=org.apache.jcs.auxiliary.disk.bdbje.BDBJECacheFactory
-jcs.auxiliary.bdbje.attributes=org.apache.jcs.auxiliary.disk.bdbje.BDBJECacheAttributes
+jcs.auxiliary.bdbje=org.apache.commons.jcs.auxiliary.disk.bdbje.BDBJECacheFactory
+jcs.auxiliary.bdbje.attributes=org.apache.commons.jcs.auxiliary.disk.bdbje.BDBJECacheAttributes
 jcs.auxiliary.bdbje.attributes.DiskPath=target/
 jcs.auxiliary.bdbje.attributes.MaxPurgatorySize=100000

Modified: commons/proper/jcs/trunk/src/conf/cacheD10A.ccf
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/conf/cacheD10A.ccf?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/conf/cacheD10A.ccf (original)
+++ commons/proper/jcs/trunk/src/conf/cacheD10A.ccf Sun Aug 25 14:17:11 2013
@@ -18,13 +18,13 @@
 # ################# DEFAULT CACHE REGION  #####################
 # sets the default aux value for any non configured caches
 jcs.default=DC,RC
-jcs.default.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.default.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.default.cacheattributes.MaxObjects=200001
-jcs.default.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.default.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.default.cacheattributes.UseMemoryShrinker=true
 jcs.default.cacheattributes.MaxMemoryIdleTimeSeconds=3600
 jcs.default.cacheattributes.ShrinkerIntervalSeconds=60
-jcs.default.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.default.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.default.elementattributes.IsEternal=false
 jcs.default.elementattributes.MaxLifeSeconds=700
 jcs.default.elementattributes.IdleTime=1800
@@ -37,27 +37,27 @@ jcs.default.elementattributes.IsLateral=
 # ################# CACHE REGIONS AVAILABLE ###################
 # Regions preconfirgured for caching
 jcs.region.testCache1=DC,RC
-jcs.region.testCache1.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.testCache1.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.testCache1.cacheattributes.MaxObjects=1000000
-jcs.region.testCache1.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.testCache1.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.region.testCache1.cacheattributes.UseMemoryShrinker=true
 jcs.region.testCache1.cacheattributes.ShrinkerIntervalSeconds=30
 jcs.region.testCache1.cacheattributes.MaxMemoryIdleTimeSeconds=300
 jcs.region.testCache1.cacheattributes.MaxSpoolPerRun=100
-jcs.region.testCache1.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.region.testCache1.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.region.testCache1.elementattributes.IsEternal=false
 jcs.region.testCache1.elementattributes.MaxLifeSeconds=60000
 jcs.region.testCache1.elementattributes.IsLateral=true
 jcs.region.testCache1.elementattributes.IsRemote=true
 
 jcs.region.testCache2=DC,RC
-jcs.region.testCache2.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.testCache2.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.testCache2.cacheattributes.MaxObjects=100
-jcs.region.testCache2.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.testCache2.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.region.testCache2.cacheattributes.UseMemoryShrinker=true
 jcs.region.testCache2.cacheattributes.MaxMemoryIdleTimeSeconds=1000
 jcs.region.testCache2.cacheattributes.ShrinkerIntervalSeconds=40
-jcs.region.testCache2.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.region.testCache2.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.region.testCache2.elementattributes.IsEternal=false
 jcs.region.testCache2.elementattributes.MaxLifeSeconds=600
 jcs.region.testCache2.elementattributes.IsSpool=true
@@ -65,13 +65,13 @@ jcs.region.testCache2.elementattributes.
 jcs.region.testCache2.elementattributes.IsLateral=true
 
 jcs.region.testCache3=
-jcs.region.testCache3.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.testCache3.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.testCache3.cacheattributes.MaxObjects=100000
-jcs.region.testCache3.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.testCache3.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.region.testCache3.cacheattributes.UseMemoryShrinker=false
 jcs.region.testCache3.cacheattributes.MaxMemoryIdleTimeSeconds=10
 jcs.region.testCache3.cacheattributes.ShrinkerIntervalSeconds=60
-jcs.region.testCache3.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.region.testCache3.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.region.testCache3.elementattributes.IsEternal=false
 jcs.region.testCache3.elementattributes.MaxLifeSeconds=3600
 jcs.region.testCache3.elementattributes.IsSpool=true
@@ -83,8 +83,8 @@ jcs.region.testCache3.elementattributes.
 # ################# AUXILIARY CACHES AVAILABLE ################
 
 # Primary Disk Cache-- faster than the rest because of memory key storage
-jcs.auxiliary.DC=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
-jcs.auxiliary.DC.attributes=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
+jcs.auxiliary.DC=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
+jcs.auxiliary.DC.attributes=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
 jcs.auxiliary.DC.attributes.DiskPath=target/test-sandbox/raf
 jcs.auxiliary.DC.attributes.MaxPurgatorySize=10000000
 jcs.auxiliary.DC.attributes.MaxKeySize=1000000
@@ -99,8 +99,8 @@ jcs.auxiliary.DC.attributes.ShutdownSpoo
 # If you want to use a separate pool for each disk cache, either use
 # the single model or define a different auxiliary for each region and use the Pooled.
 # SINGLE is best unless you ahve a huge # of regions.
-jcs.auxiliary.DC2=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
-jcs.auxiliary.DC2.attributes=org.apache.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
+jcs.auxiliary.DC2=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheFactory
+jcs.auxiliary.DC2.attributes=org.apache.commons.jcs.auxiliary.disk.indexed.IndexedDiskCacheAttributes
 jcs.auxiliary.DC2.attributes.DiskPath=target/test-sandbox/raf
 jcs.auxiliary.DC2.attributes.MaxPurgatorySize=10000
 jcs.auxiliary.DC2.attributes.MaxKeySize=10000
@@ -112,8 +112,8 @@ jcs.auxiliary.DC2.attributes.EventQueueP
 
 # need to make put or invalidate an option
 # just a remove lock to add
-jcs.auxiliary.RC=org.apache.jcs.auxiliary.remote.RemoteCacheFactory
-jcs.auxiliary.RC.attributes=org.apache.jcs.auxiliary.remote.RemoteCacheAttributes
+jcs.auxiliary.RC=org.apache.commons.jcs.auxiliary.remote.RemoteCacheFactory
+jcs.auxiliary.RC.attributes=org.apache.commons.jcs.auxiliary.remote.RemoteCacheAttributes
 jcs.auxiliary.RC.attributes.FailoverServers=dev10.hq.site59.com:1101
 jcs.auxiliary.RC.attributes.LocalPort=1200
 jcs.auxiliary.RC.attributes.RemoveUponRemotePut=false
@@ -124,8 +124,8 @@ jcs.auxiliary.RC.attributes.RemoveUponRe
 # jcs.auxiliary.RC.attributes.GetOnly=false
 
 # Remote RMI Cache set up to failover
-jcs.auxiliary.RFailover=org.apache.jcs.auxiliary.remote.RemoteCacheFactory
-jcs.auxiliary.RFailover.attributes=org.apache.jcs.auxiliary.remote.RemoteCacheAttributes
+jcs.auxiliary.RFailover=org.apache.commons.jcs.auxiliary.remote.RemoteCacheFactory
+jcs.auxiliary.RFailover.attributes=org.apache.commons.jcs.auxiliary.remote.RemoteCacheAttributes
 jcs.auxiliary.RFailover.attributes.FailoverServers=dev10.hq.site59.com:1101
 jcs.auxiliary.RC.attributes.RemoveUponRemotePut=true
 jcs.auxiliary.RFailover.attributes.GetOnly=false
--- commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/file/FileContentTypeTest.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/file/FileContentTypeTest.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.file;
+package org.apache.commons.jcs.yajcache.file;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -23,7 +23,7 @@ import junit.framework.*;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 /**
  *
@@ -34,7 +34,7 @@ import org.apache.jcs.yajcache.lang.anno
 public class FileContentTypeTest extends TestCase {
     private Log log = LogFactory.getLog(this.getClass());
     /**
      * Test of toByte method, of class org.apache.jcs.yajcache.config.FileContentType.
      */
     public void test() {
         log.debug("test toByte");
@@ -34,7 +34,7 @@ import org.apache.jcs.yajcache.lang.anno
     private Log log = LogFactory.getLog(this.getClass());
     /**
-     * Test of toByte method, of class org.apache.jcs.yajcache.config.FileContentType.
+     * Test of toByte method, of class org.apache.commons.jcs.yajcache.config.FileContentType.
      */
     public void test() {

Modified: commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/lang/annotation/CopyRightApacheTest.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/lang/annotation/CopyRightApacheTest.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/util/SerializeUtilsTest.java (original)
+++ commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/util/SerializeUtilsTest.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.yajcache.util;
+package org.apache.commons.jcs.yajcache.util;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -23,7 +23,7 @@ import junit.framework.*;
 import java.util.Arrays;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.yajcache.lang.annotation.*;
+import org.apache.commons.jcs.yajcache.lang.annotation.*;
 
 /**
  *
@@ -34,7 +34,7 @@ import org.apache.jcs.yajcache.lang.anno
 public class SerializeUtilsTest extends TestCase {
     private Log log = LogFactory.getLog(this.getClass());
     /**
      * Test of dup method, of class org.apache.jcs.yajcache.util.SerializeUtils.
      */
     public void testDup() {
         // Test string dup: no clone
@@ -34,7 +34,7 @@ import org.apache.jcs.yajcache.lang.anno
     private Log log = LogFactory.getLog(this.getClass());
     /**
-     * Test of dup method, of class org.apache.jcs.yajcache.util.SerializeUtils.
+     * Test of dup method, of class org.apache.commons.jcs.yajcache.util.SerializeUtils.
      */
     public void testDup() {

Modified: commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/util/TestSerializable.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/sandbox/yajcache/test/org/apache/jcs/yajcache/util/TestSerializable.java?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================